@@ -1,4 +1,4 @@
 def execute(*args, **kwargs):
     print(f"Welcome to pnplabs!")
-    print(f"In order to use our command shortcuts, first connect with an API Key using the 'connect' command.\n"
+    print(f"In order to use your commands, first connect with an API Key using the 'connect' command.\n"
           f"Run: 'pnplabs connect <API Key>' using the API Key provided at http://pnplabs.io/getstarted")
